searchData={"items":[{"type":"module","title":"Designex","doc":"# Designex\n\nMix tasks for installing and invoking [designex](https://github.com/netoum/designex_cli) via the\nstand-alone [designex cli](https://github.com/netoum/designex_cli/releases/tag/v1.0.2)","ref":"Designex.html"},{"type":"module","title":"Installation - Designex","doc":"If you are going to build assets in production, then you add\n`designex` as dependency on all environments but only start it\nin dev:\n\n```elixir\ndef deps do\n[\n  {:designex, \"~> 1.0\", runtime: Mix.env() == :dev}\n]\nend\n```\n\nHowever, if your assets are precompiled during development,\nthen it only needs to be a dev dependency:\n\n```elixir\ndef deps do\n[\n  {:designex, \"~> 1.0\", only: :dev}\n]\nend\n```\n\nOnce installed, change your `config/config.exs` to pick your\ndesignex version of choice:\n\n```elixir\nconfig :designex,\nversion: \"1.0.2\",\ncommit: \"1da4b31\",\ncd: Path.expand(\"../assets\", __DIR__),\ndir: \"design\",\ndemo: [\n  setup_args: ~w(\n  --dir=demo\n  --template=shadcn/tokens-studio/single\n),\n  build_args: ~w(\n  --dir=demo\n  --script=build.mjs\n  --tokens=tokens\n)\n]\n```\n\nNow you can install designex by running:\n\n```bash\n$ mix designex.install\n```\n\nThe executable is kept at `_build/designex-TARGET`.\nWhere `TARGET` is your system target architecture.\n\nIf your platform isn't officially supported by Designex,\nyou can supply a third party path to the binary the installer wants\n(beware that we cannot guarantee the compatibility of any third party executable):\nThe installer also copy the node_modules needed into the assets path. Oclif currently do not pack dependencies\n\n```bash\n$ mix designex.install https://people.freebsd.org/~dch/pub/designex/v0.0.1/designex-linux-x64\n```\n\nIf you already use Node and have a node_modules folder, you must install the dependencies seperatly by by adding them to your package.json\n\n```bash\n$ mix designex.install --no-deps\n```\nThen in you package.json add the dependencies needed by your scripts\n\"dependencies\": {\n  \"@tokens-studio/sd-transforms\": \"^1.2.9\",\n  \"sd-tailwindcss-transformer\": \"^2.0.0\",\n  \"style-dictionary\": \"^4.3.0\"\n},","ref":"Designex.html#module-installation"},{"type":"module","title":"Profiles - Designex","doc":"The first argument to `designex` is the execution profile.\nYou can define multiple execution profiles with the current\ndirectory, the OS environment, and default arguments to the\n`designex` task:\n\n```elixir\ndemo: [\n  setup_args: ~w(\n  --dir=demo\n  --template=shadcn/tokens-studio/single\n),\n  build_args: ~w(\n  --dir=demo\n  --script=build.mjs\n  --tokens=tokens\n)\n],\nemail: [\n  setup_args: ~w(\n  --dir=email\n  --template=shadcn/tokens-studio/multi\n),\n  build_args: ~w(\n  --dir=email\n  --script=build.mjs\n  --tokens=tokens\n)\n]\n```\n\nWhen `mix designex demo` is invoked, the task arguments will be appended\nto the ones configured above. Note profiles must be configured in your\n`config/config.exs`, as `designex` runs without starting your application\n(and therefore it won't pick settings in `config/runtime.exs`).","ref":"Designex.html#module-profiles"},{"type":"module","title":"Designex Setup - Designex","doc":"To setup Invoke Designex Setup with your profile:\n\n```bash\n$ mix designex.setup demo\n$ mix designex.setup email\n\n```\n\nYou can choose the template and directory by adding them to your designex profile","ref":"Designex.html#module-designex-setup"},{"type":"module","title":"Designex build - Designex","doc":"To setup Invoke Designex Build with your profile:\n\n```bash\n$ mix designex demo\n$ mix designex email\n```\nor\n```bash\n$ mix designex.build demo\n$ mix designex.build email\n```\n\nYou can choose the template and directory by adding them to your designex profile","ref":"Designex.html#module-designex-build"},{"type":"module","title":"Watch Mode - Designex","doc":"For development, we want to enable watch mode. So find the `watchers`\nconfiguration in your `config/dev.exs` and add:\n\n```elixir\ndesignex: {Tailwind, :install_and_run, [:default, ~w(--watch)]}\n```\n\nNote we are enabling the file system watcher.\n\nFinally, run the command:\n\n```bash\n$ mix designex default\n```\n\nThis command installs the Design tokens and scripts.\nIt also generates a default configuration file called\n`designex.config.js` for you. This is the file we referenced\nwhen we configured `designex` in `config/config.exs`. See\n`mix help designex.install` to learn more.","ref":"Designex.html#module-watch-mode"},{"type":"module","title":"Designex configuration - Designex","doc":"There are two global configurations for the designex application:\n\n  * `:version` - the expected designex version\n\n  * `:commit` - the expected designex commit\n\n  * `:cacerts_path` - the directory to find certificates for\n    https connections\n\n  * `:path` - the path to find the designex executable at. By\n    default, it is automatically downloaded and placed inside\n    the `_build` directory of your current app\n\nOverriding the `:path` is not recommended, as we will automatically\ndownload and manage `designex` for you. But in case you can't download\nit (for example, GitHub behind a proxy), you may want to\nset the `:path` to a configurable system location.\n\nFor instance, you can install `designex` globally with `npm`:\n\n    $ npm install -g designex\n\nOn Unix, the executable will be at:\n\n    NPM_ROOT/designex/node_modules/designex-TARGET/bin/designex\n\nOn Windows, it will be at:\n\n    NPM_ROOT/designex/node_modules/designex-windows-(32|64)/designex.exe\n\nWhere `NPM_ROOT` is the result of `npm root -g` and `TARGET` is your system\ntarget architecture.\n\nOnce you find the location of the executable, you can store it in a\n`MIX_DESIGNEX_PATH` environment variable, which you can then read in\nyour configuration file:\n\n    config :designex, path: System.get_env(\"MIX_DESIGNEX_PATH\")","ref":"Designex.html#module-designex-configuration"},{"type":"function","title":"Designex.bin_path/0","doc":"Returns the path to the executable.\n\nThe executable may not be available if it was not yet installed.","ref":"Designex.html#bin_path/0"},{"type":"function","title":"Designex.bin_version/0","doc":"Returns the version of the designex executable.\n\nReturns `{:ok, version_string}` on success or `:error` when the executable\nis not available.","ref":"Designex.html#bin_version/0"},{"type":"function","title":"Designex.config_for!/1","doc":"Returns the configuration for the given profile.\n\nReturns nil if the profile does not exist.","ref":"Designex.html#config_for!/1"},{"type":"function","title":"Designex.configured_cd/0","doc":"Returns the configured cd directory path.","ref":"Designex.html#configured_cd/0"},{"type":"function","title":"Designex.configured_commit/0","doc":"Returns the configured designex version.","ref":"Designex.html#configured_commit/0"},{"type":"function","title":"Designex.configured_dir/0","doc":"Returns the configured designex directory name.","ref":"Designex.html#configured_dir/0"},{"type":"function","title":"Designex.configured_version/0","doc":"Returns the configured designex version.","ref":"Designex.html#configured_version/0"},{"type":"function","title":"Designex.default_base_url/0","doc":"The default URL to install Designex from.","ref":"Designex.html#default_base_url/0"},{"type":"function","title":"Designex.extract_path/0","doc":"","ref":"Designex.html#extract_path/0"},{"type":"function","title":"Designex.install/2","doc":"Installs designex with `configured_version/0`.","ref":"Designex.html#install/2"},{"type":"function","title":"Designex.install_and_run/2","doc":"Installs, if not available, and then runs `designex`.\n\nReturns the same as `run/2`.","ref":"Designex.html#install_and_run/2"},{"type":"function","title":"Designex.profile_path/1","doc":"Returns the configured designex directory name.","ref":"Designex.html#profile_path/1"},{"type":"function","title":"Designex.run/2","doc":"Runs the given command with `args`.\n\nThe given args will be appended to the configured args.\nThe task output will be streamed directly to stdio. It\nreturns the status of the underlying call.","ref":"Designex.html#run/2"},{"type":"function","title":"Designex.setup/2","doc":"Runs the given command with `args`.\n\nThe given args will be appended to the configured args.\nThe task output will be streamed directly to stdio. It\nreturns the status of the underlying call.","ref":"Designex.html#setup/2"},{"type":"task","title":"mix designex","doc":"","ref":"Mix.Tasks.Designex.html"},{"type":"function","title":"Mix.Tasks.Designex.run/1","doc":"","ref":"Mix.Tasks.Designex.html#run/1"},{"type":"task","title":"mix designex.build","doc":"Invokes designex with the given args.\n\nUsage:\n\n    $ mix designex TASK_OPTIONS PROFILE TAILWIND_ARGS\n\nExample:\n\n    $ mix designex default --config=designex.config.js       --input=css/app.css       --output=../priv/static/assets/app.css       --minify\n\nIf designex is not installed, it is automatically downloaded.\nNote the arguments given to this task will be appended\nto any configured arguments.","ref":"Mix.Tasks.Designex.Build.html"},{"type":"task","title":"Options - mix designex.build","doc":"* `--runtime-config` - load the runtime configuration\n    before executing command\n\nNote flags to control this Mix task must be given before the\nprofile:\n\n    $ mix designex --runtime-config default","ref":"Mix.Tasks.Designex.Build.html#module-options"},{"type":"task","title":"mix designex.install","doc":"Installs Designex executable and assets.\n\n    $ mix designex.install\n    $ mix designex.install --if-missing\n\nBy default, it installs 1.0.2 but you\ncan configure it in your config files, such as:\n\n    config :designex, :version, \"1.0.2\"","ref":"Mix.Tasks.Designex.Install.html"},{"type":"task","title":"Options - mix designex.install","doc":"* `--runtime-config` - load the runtime configuration\n      before executing command\n\n    * `--if-missing` - install only if the given version\n      does not exist\n\n    * `--no-deps` - does not install Designex Node dependencies. Use this in case you already have a node_modules folder.\n    Add instead the dependencies to your own package.json\n\n      \"dependencies\": {\n      \"@tokens-studio/sd-transforms\": \"^1.2.9\",\n      \"sd-tailwindcss-transformer\": \"^2.0.0\",\n      \"style-dictionary\": \"^4.3.0\"\n      }","ref":"Mix.Tasks.Designex.Install.html#module-options"},{"type":"task","title":"Assets - mix designex.install","doc":"Whenever Designex is installed, a default designex configuration\nwill be placed in a new `assets/designex.config.js` file. See\nthe [designex documentation](https://tailwindcss.com/docs/configuration)\non configuration options.\n\nThe default designex configuration includes Designex variants for Phoenix\nLiveView specific lifecycle classes:\n\n  * phx-no-feedback - applied when feedback should be hidden from the user\n  * phx-click-loading - applied when an event is sent to the server on click\n    while the client awaits the server response\n  * phx-submit-loading - applied when a form is submitted while the client awaits the server response\n  * phx-submit-loading - applied when a form input is changed while the client awaits the server response\n\nTherefore, you may apply a variant, such as `phx-click-loading:animate-pulse`\nto customize designex classes when Phoenix LiveView classes are applied.","ref":"Mix.Tasks.Designex.Install.html#module-assets"},{"type":"task","title":"mix designex.setup","doc":"Invokes designex with the given args.\n\nUsage:\n\n    $ mix designex TASK_OPTIONS PROFILE TAILWIND_ARGS\n\nExample:\n\n    $ mix designex default --config=designex.config.js       --input=css/app.css       --output=../priv/static/assets/app.css       --minify\n\nIf designex is not installed, it is automatically downloaded.\nNote the arguments given to this task will be appended\nto any configured arguments.","ref":"Mix.Tasks.Designex.Setup.html"},{"type":"task","title":"Options - mix designex.setup","doc":"* `--runtime-config` - load the runtime configuration\n    before executing command\n\nNote flags to control this Mix task must be given before the\nprofile:\n\n    $ mix designex --runtime-config default","ref":"Mix.Tasks.Designex.Setup.html#module-options"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}